### Stellar Lines Of Planets with Python
***
### `SLOPpy` version 1.0 - August 2022

**Main contributors**
Daniela Sicilia
Luca Malavolta
Lorenzo Pino
Gaetano Scandariato
Valerio Nascimbeni
Giampaolo Piotto
Isabella Pagano

**News**
Paper accepted, first public commit, link coming soon

Most of the information can be found in [Sicilia et al. (2022)](https://ui.adsabs.harvard.edu//#abs/########/abstract).
